# ape.managers

## Accounts

```{eval-rst}
.. automodule:: ape.managers.accounts
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

## Compilers

```{eval-rst}
.. automodule:: ape.managers.compilers
    :members:
```

## Chain

```{eval-rst}
.. autoclass:: ape.managers.chain.AccountHistory
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.chain.ContractCache
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.chain.BlockContainer
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.chain.ChainManager
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

## Config

```{eval-rst}
.. automodule:: ape.managers.config
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

## Converters

```{eval-rst}
.. automodule:: ape.managers.converters
    :members:
```

## Networks

```{eval-rst}
.. automodule:: ape.managers.networks
    :members:
```

## Project

```{eval-rst}
.. automodule:: ape.managers.project.manager
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. automodule:: ape.managers.project.dependency
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.project.types.BaseProject
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.project.types.ApeProject
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.managers.project.types.BrownieProject
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

## Query

```{eval-rst}
.. automodule:: ape.managers.query
    :members:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```
